OC.L10N.register(
    "comments",
    {
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien",
    "%1$s commented" : "%1$s kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentiert %2$s",
    "Comments" : "Kommentare",
    "Type in a new comment..." : "Gebe bitte einen neuen Kommentar ein...",
    "Delete comment" : "Kommentar löschen",
    "Post" : "Speichern",
    "Cancel" : "Abbrechen",
    "Edit comment" : "Kommentar bearbeiten",
    "[Deleted user]" : "[Gelöschter Benutzer]",
    "No other comments available" : "Keine andere Kommentare vorhanden",
    "More comments..." : "Weitere Kommentare...",
    "Save" : "Speichern",
    "Allowed characters {count} of {max}" : "Erlaubte Zeichen {count} von {max}",
    "{count} unread comments" : "{count} ungelesene Kommentare",
    "Comment" : "Kommentar",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien"
},
"nplurals=2; plural=(n != 1);");
